@@ -6,7 +6,7 @@
 // not use this file except in compliance with the License.
 // You may obtain a copy of the License at
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
+//	http://www.apache.org/licenses/LICENSE-2.0
 //
 // Unless required by applicable law or agreed to in writing,
 // software distributed under the License is distributed on an
@@ -14,14 +14,21 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
-//
+
+// Package observability provides metrics, profiling, and etc.
 package observability
 
+import "errors"
+
+var errNoAddr = errors.New("no address")
+
+// Statistics represents a sample of a module.
 type Statistics struct {
 	MemBytes    int64
 	MaxMemBytes int64
 }
 
+// Observable allows sampling.
 type Observable interface {
 	Stats() Statistics
 }
